/* NAME:
 *	tcp - TCP/IP support routines
 *
 *
 * AUTHOR:
 *	Simon Gerraty <sjg@crufty.net>
 */
/*
 * RCSid:
 *	$Id: tcp.h,v 1.19 2002/12/13 06:47:25 sjg Exp $
 *
 *	@(#)Copyright (c) 1994, Simon J. Gerraty.
 *	
 *	This is free software.	It comes with NO WARRANTY.
 *	Permission to use, modify and distribute this source code 
 *	is granted subject to the following conditions.
 *	1/ that the above copyright notice and this notice 
 *	are preserved in all copies and that due credit be given 
 *	to the author.	
 *	2/ that any changes to this code are clearly commented 
 *	as such so that the author does not get blamed for bugs 
 *	other than his own.
 *	
 *	Please send copies of changes and bug-fixes to:
 *	sjg@crufty.net
 */

#ifndef _SJG_TCP_H
# define _SJG_TCP_H

#include <sys/types.h>
#include <sys/cdefs.h>
#include "sjg/extern.h"

/*
 * flags to pass to tcp_listen()
 */
#define TCPL_ONCE	(1<<0)
#define TCPL_FORK	(1<<1)
#define TCPL_SYSLOG	(1<<2)
#define TCPL_LOOKUP	(1<<3)		/* IPCIDF_PARANOID */
#define TCPL_STDIN	(1<<4)		/* make socket stdin etc */

/*
 * flags for inted_init()
 */
#define INIF_TIMEOUT	(1<<0)
#define INIF_LOOKUP	(1<<1)
#define INIF_INFO	(1<<2)
#define INIF_STDIN	(1<<3)
#define INIF_NOFORK	(1<<4)

EXTERN int Debug;

#ifdef sun386
typedef int pid_t;
#endif
#endif /* _TCP_H */

struct sockaddr_in;

__BEGIN_DECLS
/*
 * These were added by updprotos, don't bother editing by hand
 */
/*bindport.c*/
int 	bind_sock	 __P((int  /*s*/, struct sockaddr_in * /*sa*/, int  /*port*/));
int 	bind_port	 __P((int  /*s*/, int  /*port*/, char * /*addr*/));
/*daemon.c*/
int 	daemon	 __P((int  /*nochdir*/, int  /*noclose*/));
pid_t 	daemon_init	 __P((int  /*ttyf*/, char * /*name*/));
int     LogPID   __P((const char * /*dir*/, const char * /*name*/, int  /*pid*/));
/*domaincmp.c*/
int 	domaincmp	 __P((const char * /*domain*/, const char * /*spec*/, int /*flags*/));
/*getipaddr.c*/
char **	get_addr_list	 __P((const char * /*host*/));
unsigned long 	get_ip_addr	 __P((char * /*host*/));
/*globals.c*/
/*inetdinit.c*/
int 	inetd_spec	 __P((const char * /*spec*/, int  /*flags*/, struct sockaddr_in * /*me*/));
int 	inetd_init	 __P((int  /*port*/, int  /*sock_type*/, int  /*flags*/, struct sockaddr_in * /*me*/));
/*ipcallid.c*/
char *	ip_caller_id	 __P((struct sockaddr_in * /*sa*/, int  /*lookup*/));
char *	sock_id	 __P((int  /*s*/, int  /*flags*/));
/*proxy_connect.c*/
int 	proxy_connect	 __P((int  /*s*/, const char * /*dest*/, char ** /*err*/));
const char *	use_proxy	 __P((const char * /*dest*/, const char * /*prefer*/));
/*pthru.c*/
int 	pthru1	 __P((int  /*s1*/, int  /*s2*/));
int 	copy	 __P((int  /*s1*/, int  /*s2*/));
int 	pthru	 __P((int  /*s1*/, int  /*s2*/));
/*s2av.c*/
char **	s2av	 __P((char * /*s*/, const char * /*tok*/, int * /*acp*/));
/*sig.c*/
void (*	Signal	 __P((int  /*sig*/, void (*/*handler*/) __P((int))))) __P((int));
/*sigchld.c*/
void 	sigchld	 __P((int  /*sig*/));
/*sigurg.c*/
void 	sigurg	 __P((int  /*sig*/));
/*sockdest.c*/
char **	sock_dest	 __P((const char * /*spec*/, struct sockaddr_in * /*sa*/, int * /*sock_type*/));
/*tcplisten.c*/
int 	tcp_listen	 __P((const char * /*listen_to*/, int  /*flags*/, int (*/*handler*/)(int, struct sockaddr_in *, void *), void * /*hargs*/));
/*tcpopen.c*/
int 	net_open	 __P((const char * /*spec*/, const char * /*mode*/));
int 	tcp_open	 __P((const char * /*host*/, int  /*port*/));


__END_DECLS
